//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[TileType](../index.md)/[Companion](index.md)/[valueOf](value-of.md)

# valueOf

[common]\
fun [valueOf](value-of.md)(ordinal: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [TileType](../index.md)
